@@ -1,6 +1,8 @@
 import os
 import sys
 
+SakRootPath = ""
+
 
 def getPath(config_name=""):
     """获取路径 返回运行本函数的文件绝对路径+config_name
@@ -14,26 +16,45 @@ def getPath(config_name=""):
     return config_path
 
 
+# 设置项目的根目录
+def setRootPath(path: str):
+    """
+        设置项目的根目录
+    @param path:
+    @return:
+    """
+    global SakRootPath
+    SakRootPath = path
+    return True
+
+
 # 获取项目根目录
 def getRootPath():
     """
         获取项目根目录
     :return:
     """
-    return getPath("..\\")
+    global SakRootPath
+    if SakRootPath == "":
+        print("请先调用 setRootPath 设置项目根目录")
+        return False
+    return SakRootPath
 
 
+# 创建目录（若路径不存在，则递归创建，若存在则不执行）
 def mkdir(path: str):
     """
-        目录
-        若目录不存在，则递归创建
-    :param path:
+        递归创建目录
+        1、若路径不存在，则递归创建。
+        2、若路径已存在，则不执行。
+    :param path: 路径
     :return:
     """
     if not os.path.exists(path):
         os.makedirs(path)
-
-    return True
+        return True
+    else:
+        return False
 
 
 def isPathExists(path: str):
